# Changelog

<!--next-version-placeholder-->

## v0.2.0 (2022-01-04)
### Feature
* Add ignore-case flag for checks ([`1cb60ac`](https://gitlab.com/TheTwitchy/shuvel/-/commit/1cb60ace13c0b08fd8cff74742afe28a1e1c4a9d))

## v0.1.0 (2021-11-15)
### Feature
* Basic code searching implementation ([`5b7aaea`](https://gitlab.com/TheTwitchy/shuvel/-/commit/5b7aaeade6b075fcb4e63250ef3c6f0edb89b937))
